import warnings


def grid_to_triple(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.grid_to_triple``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.grid_to_triple``.")

    return None


def linint1(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint1``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint1``.")

    return None


def linint2(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint2``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint2``.")

    return None


def linint2pts(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.linint2pts``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.linint2pts``.")

    return None


def moc_globe_atl(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.moc_globe_atl``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.moc_globe_atl``.")

    return None


def rcm2points(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rcm2points``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rcm2points``.")

    return None


def rcm2rgrid(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rcm2rgrid``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rcm2rgrid``.")

    return None


def rgrid2rcm(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.rgrid2rcm``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.rgrid2rcm``.")

    return None


def triple_to_grid(*args, **kwargs):
    r"""
    .. deprecated:: 2023.06.0
      To use this function, install the geocat-f2py package and import as
      ``geocat.f2py.triple_to_grid``.

    """
    warnings.warn(
        "To use this function, install the geocat-f2py package and import as "
        "``geocat.f2py.triple_to_grid``.")

    return None



# move functions into geocat.comp namespace
from .climatologies import (
    month_to_season,
    calendar_average,
    climatology_average,
    climate_anomaly,
)
from .fourier_filters import (
    fourier_band_block,
    fourier_band_pass,
    fourier_filter,
    fourier_high_pass,
    fourier_low_pass,
)
from .gradient import gradient, _arc_lon_wgs84, _arc_lat_wgs84, _rad_lat_wgs84
from .interpolation import (
    interp_hybrid_to_pressure,
    interp_sigma_to_hybrid,
    interp_multidim,
)
from .meteorology import (
    dewtemp,
    heat_index,
    relhum,
    relhum_ice,
    relhum_water,
    actual_saturation_vapor_pressure,
    max_daylight,
    psychrometric_constant,
    saturation_vapor_pressure,
    saturation_vapor_pressure_slope,
    delta_pressure,
    dpres_plev,
)
from .spherical import decomposition, recomposition, scale_voronoi
from .stats import eofunc, eofunc_eofs, eofunc_pcs, eofunc_ts, pearson_r
from .deprecated import (
    grid_to_triple,
    linint1,
    linint2,
    linint2pts,
    moc_globe_atl,
    rcm2points,
    rcm2rgrid,
    rgrid2rcm,
    triple_to_grid,
)

# get version from pyproject.toml
from importlib.metadata import version as _version

try:
    __version__ = _version("geocat.comp")
except Exception:
    # Local copy or not installed with setuptools.
    # Disable minimum version checks on downstream libraries.
    __version__ = "999"
